'****************************************************************
'*  Name    : Eight7SegDisplay.BAS                              *
'*  Author  : [Alberto Freixanet]                               *
'*  Notice  : Copyright (c) 2018 [No Copyright]                 *
'*          : All Rights Reserved                               *
'*  Date    : 04/07/2018                                        *
'*  Version : 1.0                                               *
'*  Notes   : Proton Basic Compiler V3.6.0.3                    *
'*          : Original code written by Les Johnson              *
'* Library  : RSOut8Digits_DemultiplexLib.Inc                   *
'****************************************************************
'/ Code for 8 seven segment display with logic interface for digit value
'/ and digit enable to reduce pins count.
'/ Using the 74HC4511 decoder, a table of segments value is not needed.
'/ Using the 74HC238 3 to 8 lines reduces the pins count.
'/ Total pins used for 8 digits = 8 only.
'/
'/ 01/07/2018 version 1.1
'/ In case of ASCII characters > 123 goto error.
'/ Moved the CR detection in Select/Case code.
'/
'/------------------------------------------------------------------------------
(*
Recommended identifiers for the RsOut command.
The modifiers are listed below:
Modifier Operation
    Bin{1..to number of digits} Send binary digits
    Dec{0..to number of digits} Send decimal digits (amount of digits after decimal point with floating point)
    Hex{1..to number of digits} Send hexadecimal digits
    Sbin{1..to number of digits} Send signed binary digits
    Sdec{0..limited} Send signed decimal digits
    Shex{1..to number of digits} Send signed hexadecimal digits
*)
'/------------------------------------------------------------------------------
    Device = 18F452
   
    Declare Xtal = 8    ' For Proteus testing
'    Declare Xtal = 40   ' For real PIC (40Mhz or 64Mhz depending the family)

    Declare Optimiser_Level = 3
    Declare Dead_Code_Remove = On
    Declare Float_Display_Type = Fast
    Declare Show_System_Variables = On
    Declare Create_Coff = On
    Declare Watchdog = OFF
    Declare Bootloader = OFF
    Declare Eeprom_Address $F00000  ' This address changes with K40/K42 PICs.
    $define _ProteusTest

'/ Configuration of the Serial comunication
    Declare Hserial_Baud = 9600                 ' Set baud rate to 9600
    Declare Hserial_RCSTA = %10010000           ' Enable serial port and continuous receive
    Declare Hserial_TXSTA = %00100100           ' Enable transmit and asynchronous mode
    Declare Hserial_Clear = On                  ' Enable Error clearing on received characters

'/ Rsout / Serial Constants
    Symbol Home = 1
    Symbol Bell = 7
    Symbol BkSp = 8
    Symbol Tab = 9
'    Symbol CR = 13
'    Symbol LF = 10    

'/ Temporal variables
    Dim TempByte As Byte
    Dim TestLoop As Word
    Dim TestNumbers As Byte

'/ Maths test variables
    Dim MyFloat As Float
    Dim MyDword As Dword
    Dim MyDword2 As Dword
    Dim MyDword3 As Dword        
    Dim MyWord As Word
    Dim MyWord1 As Word
    Dim MyWord2 As Word
    Dim MyWord3 As Word
    Dim MyWord4 As Word                 
    Dim MyByte As Byte
    
    Dim MySDword As SDword
    Dim MySDword2 As SDword    
    Dim MySWord As SWord 
    Dim MySByte As SByte            

    Dim MyASCIIarray As String * 8
'===============================================================================
'    Include "D:\MyIncFiles\RSOut8Digits_DemuV11_Lib.Inc"
    Include "RSOut8Digits_DemuV11_Lib.Inc"
'===============================================================================
MAIN_CODE:
    DelayMS 200
    HRSOut "RUNNING 3 TO 8 SEGMENTS DISPLAY WITH THE RSOUT COMMAND!", CR,LF 
 
    $if _Hardware = 0
    HRSOut "DISPLAY RUNNING IN COMMON CATHODE MODE WITH 74HC238 + ULN2803", CR,LF    
    $else
    HRSOut "DISPLAY RUNNING IN COMMON ANODE MODE WITH 74HC238 + UDN2981A", CR,LF     
    $endif    

    $if NumberDigits = 8
    HRSOut "DISPLAY RUNNING WITH 8 DIGITS", CR,LF     
    $endif
    $if NumberDigits = 7
    HRSOut "DISPLAY RUNNING WITH 7 DIGITS", CR,LF     
    $endif
    $if NumberDigits = 6
    HRSOut "DISPLAY RUNNING WITH 6 DIGITS", CR,LF     
    $endif
    $if NumberDigits = 5
    HRSOut "DISPLAY RUNNING WITH 5 DIGITS", CR,LF     
    $endif
    $if NumberDigits = 4
    HRSOut "DISPLAY RUNNING WITH 4 DIGITS", CR,LF     
    $endif
    $if NumberDigits = 3
    HRSOut "DISPLAY RUNNING WITH 3 DIGITS", CR,LF     
    $endif

    HRSOut "DISPLAY INITIALIZED & TEST IS RUNNING", CR,LF
    HRSOut CR,LF
'===============================================================================
Multiplex:

$if NumberDigits = 8
'    '/ Test error of number of character.
'    RsOut "aaaaa}",CR 
'    DelayMS 3000

'    '/ Test error of number of digits.
'    MyDword = 123456789234
'    RsOut Dec MyDword, CR
'    DelayMS 500

'    MyDword = 123456
'    RsOut Dec MyDword, CR
'    DelayMS 250
        
'    MyDword = 935
'    RsOut Dec MyDword, CR
'    DelayMS 300
    
'    DelayMS 300
'    GoTo Multiplex

    MyASCIIarray = "ABCDEFGH"
    RsOut Str MyASCIIarray\8,CR    
    DelayMS 2500

    MyASCIIarray = "IJKLMNOP"
    RsOut Str MyASCIIarray\8,CR    
    DelayMS 2500

    MyASCIIarray = "QRSTUVWX"
    RsOut Str MyASCIIarray\8,CR    
    DelayMS 2500
    
    MyASCIIarray = "YZ:;=ABC"
    RsOut Str MyASCIIarray\8,CR    
    DelayMS 2500    

'    MyASCIIarray = "EEEEEEEE"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000

'    MyASCIIarray = "FFFFFFFF"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000
    
'    MyASCIIarray = "GGGGGGGG"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000    
    
'    MyASCIIarray = "HHHHHHHH"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000

'    MyASCIIarray = "IIIIIIII"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000
    
'    MyASCIIarray = "JJJJJJJJ"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000    

'    MyASCIIarray = "KKKKKKKK"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000
    
'    MyASCIIarray = "LLLLLLLL"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000

'    MyASCIIarray = "MMMMMMMM"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000

'    MyASCIIarray = "NNNNNNNN"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000

'    MyASCIIarray = "OOOOOOOO"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000
    
'    MyASCIIarray = "PPPPPPPP"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000

'    MyASCIIarray = "QQQQQQQQ"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000                

'    MyASCIIarray = "RRRRRRRR"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000

'    MyASCIIarray = "SSSSSSSS"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000
    
'    MyASCIIarray = "TTTTTTTT"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000    

'    MyASCIIarray = "UUUUUUUU"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000

'    MyASCIIarray = "VVVVVVVV"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000
    
'    MyASCIIarray = "WWWWWWWW"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000
    
'    MyASCIIarray = "XXXXXXXX"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000

'    MyASCIIarray = "YYYYYYYY"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000

'    MyASCIIarray = "ZZZZZZZZ"
'    RsOut Str MyASCIIarray\8,CR    
'    DelayMS 1000
                
'    GoTo Multiplex
$endif
$if NumberDigits = 8
Maths_Sub:
    '/ Some Maths with integers.
    MyWord = 15641
    MyWord1 = 36

    HRSOut "Some Maths with integers: -434.472", CR, LF
    MyWord2 = MyWord / MyWord1  '/ Result = 434
    MyWord3 = MyWord // MyWord1 '/ Remainder = 17 
    MyWord3 = MyWord3 * 1000    '/ Remainder * 1000 = 17000 (*1000 for 3 decimals)
    MyWord4 = MyWord3 / MyWord1 '/ (Remainder * 1000) / 36 = 472 (decimals)

    RsOut "-",Dec MyWord2,".",Dec MyWord4,CR
    DelayMS 2000

    '/ Some Maths with Float.
    HRSOut "Some Maths with Float: 434.472", CR, LF
    MyFloat = 15641.0
    MyFloat = MyFloat / MyWord1
    RsOut Dec3 MyFloat,CR
    DelayMS 2000

'    GoTo Multiplex

Multiplex2:
    MyASCIIarray = "COMPILER"
    HRSOut "MyASCIIarray: ", Str MyASCIIarray\8, CR, LF 
    RsOut Str MyASCIIarray\8,CR
    DelayMS 2000

    MyASCIIarray = "MY:PDS"
    HRSOut "MyASCIIarray: ", Str MyASCIIarray\6, CR, LF 
    RsOut Str MyASCIIarray\6,CR
    DelayMS 2000

    MyASCIIarray = "STOP"
    HRSOut "MyASCIIarray: ", Str MyASCIIarray\4, CR, LF 
    RsOut Str MyASCIIarray\4,CR
    DelayMS 2000

    MyASCIIarray = "ENTER"
    HRSOut "MyASCIIarray: ", Str MyASCIIarray\5, CR, LF 
    RsOut Str MyASCIIarray\5,CR
    DelayMS 2000

    MyASCIIarray = "SUNDAY"
    HRSOut "MyASCIIarray: ", Str MyASCIIarray\6, CR, LF 
    RsOut Str MyASCIIarray\6,CR
    DelayMS 2000

    MyASCIIarray = "MONDAY"
    HRSOut "MyASCIIarray: ", Str MyASCIIarray\6, CR, LF 
    RsOut Str MyASCIIarray\6,CR
    DelayMS 2000

    MyASCIIarray = "RESULT"
    HRSOut "MyASCIIarray: ", Str MyASCIIarray\6, CR, LF 
    RsOut Str MyASCIIarray\6,CR
    DelayMS 2000
    
    MyASCIIarray = "OUTPUT"
    HRSOut "MyASCIIarray: ", Str MyASCIIarray\6, CR, LF 
    RsOut Str MyASCIIarray\6,CR
    DelayMS 2000

    MyASCIIarray = "STANDBY"
    HRSOut "MyASCIIarray: ", Str MyASCIIarray\7, CR, LF 
    RsOut Str MyASCIIarray\7,CR
    DelayMS 2000

    MyASCIIarray = "NO:ERROR"
    HRSOut "MyASCIIarray: ", Str MyASCIIarray\8, CR, LF 
    RsOut Str MyASCIIarray\8,CR
    DelayMS 2000
$endif    

'    GoTo Multiplex 
'/------------------------------------------------------------------------------
$if NumberDigits = 8
    HRSOut "Write Integer; 1 number: ", CR, LF
    MyDword = 6
'    PrintDispInt(Dec, MyDword)
    RsOut Dec MyDword, CR
    HRSOut "MyDword: ", Dec MyDword, CR, LF  
    HRSOut CR, LF
    DelayMS 1000
    
    HRSOut "Write Integer; 2 numbers: ", CR, LF
    MyDword = 12
'    PrintDispInt(Dec, MyDword)
    PrintDisp(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF    
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 3 numbers: ", CR, LF
    MyDword = 123
'    PrintDispInt(Dec, MyDword)
    PrintDisp(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 4 numbers: ", CR, LF
    MyDword = 1234
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 5 numbers: ", CR, LF
    MyDword = 12345
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 6 numbers: ", CR, LF
    MyDword = 123456
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 7 numbers: ", CR, LF
    MyDword = 1234567
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 8 numbers: ", CR, LF
    MyDword = 12345678
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000
    
    HRSOut "Write Integer HEX; 2 numbers: ", CR, LF
    MyDword = 12
    PrintDispInt(Hex2, MyDword)
    HRSOut "MyDword: ", Hex2 MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Integer HEX; 4 numbers: ", CR, LF
    MyDword = 1234
'    PrintDispInt(Hex4, MyDword)
    PrintDisp(Hex4, MyDword)
    HRSOut "MyDword: ", Hex4 MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Float, 3 decimals: ", CR, LF
    MyFloat = 3.145
'    PrintDispFlt(Dec3, MyFloat)
    PrintDisp(Dec3, MyFloat)
    HRSOut "MyFloat: ", Dec3 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000
 
    HRSOut "Write Float, 1 decimal: ", CR, LF
    MyFloat = 3.145
    PrintDispFlt(Dec1, MyFloat)
    HRSOut "MyFloat: ", Dec1 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000 
    
    HRSOut "Write Negative number: SDword ", CR, LF
    MySDword = -37340
    PrintDispSign(SDec, MySDword)
    HRSOut "MySDword: ", SDec MySDword, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Negative number: SWord  ", CR, LF
    MySWord = -12345
    PrintDispSign(SDec, MySWord)
    HRSOut "MySWord: ", SDec MySWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write negative character + 1 number: ", CR, LF
    MyDword = 4567
    RsOut "-"
    PrintDispInt(Dec, MyDword)
    HRSOut "- MyDword: ", "-", Dec MyDword, CR, LF
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Negative HEX number: ", CR, LF
    MySDword = -5678
    PrintDispSign(SHex4, MySDword)
    HRSOut "MySDword: ", SHex4 MySDword, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    MyWord = 195
    HRSOut "Write Binary number: ", Dec MyWord, CR, LF
    PrintDispInt(Bin8, MyWord)
    HRSOut "MyWord: ", Bin8 MyWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

'    MyDword = 15641
'    MyWord = 36

'    MyDword2 = MyDword / MyWord
'    MyDword3 = MyDword // MyWord
'    MyDword3 = MyDword3 / MyWord
'    HRSOut "Result: 434.472", CR, LF
'    RsOut Dec MyDword2, "", Dec3 MyDword3,CR
'    DelayMS 2000
    
    HRSOut "END OF TEST: NOW COUNTING... ", CR, LF, CR, LF

    TestNumbers = 0
    TestLoop = 0
    MyDword = 99999
    Repeat
        HRSOut Dec MyDword,","
        PrintDispInt(Dec, MyDword)      '/ Extract the individual digits of MyDWord
        DelayMS 150
        MyDword = MyDword + 500001
        Inc TestNumbers
        If TestNumbers = 20 Then
            TestNumbers = 0
            HRSOut CR,LF
        EndIf
        Inc TestLoop 
    Until TestLoop > 198
    PrintDispInt(Dec, MyDword)          '/ Extract the individual digits of MyDWord
    HRSOut Dec MyDword
    HRSOut CR,LF,CR,LF
$endif
'/------------------------------------------------------------------------------
$if NumberDigits = 7
    HRSOut "Write Integer; 1 number: ", CR, LF
    MyDword = 6
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000
    
    HRSOut "Write Integer; 2 numbers: ", CR, LF
    MyDword = 12
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 3 numbers: ", CR, LF
    MyDword = 123
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 4 numbers: ", CR, LF
    MyDword = 1234
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 5 numbers: ", CR, LF
    MyDword = 12345
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 6 numbers: ", CR, LF
    MyDword = 123456
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 7 numbers: ", CR, LF
    MyDword = 1234567
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer HEX; 3 numbers: ", CR, LF
    MyDword = 234
    PrintDispInt(Hex2, MyDword)
    HRSOut "MyDword: ", Hex2 MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Integer HEX; 5 numbers: ", CR, LF
    MyDword = 12348
    PrintDispInt(Hex4, MyDword)
    HRSOut "MyDword: ", Hex4 MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Float, 3 decimals: ", CR, LF
    MyFloat = 3.145
    PrintDispFlt(Dec3, MyFloat)
    HRSOut "MyFloat: ", Dec3 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000
 
    HRSOut "Write Float, 1 decimal: ", CR, LF
    MyFloat = 3.145
    PrintDispFlt(Dec1, MyFloat)
    HRSOut "MyFloat: ", Dec1 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000 
    
    HRSOut "Write Negative number: SDword ", CR, LF
    MySDword = -12345
    PrintDispSign(SDec, MySDword)
    HRSOut "MySDword: ", SDec MySDword, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write minus number: SWord  ", CR, LF
    MySWord = -12345
    PrintDispSign(SDec, MySWord)
    HRSOut "MySWord: ", SDec MySWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write minus character + 1 number: ", CR, LF
    MyDword = 4567
    RsOut "-"
    PrintDispInt(Dec, MyDword)
    HRSOut "- MyDword: ", "-", Dec MyDword, CR, LF
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Negative HEX number: ", CR, LF
    MySDword = -5678
    PrintDispSign(SHex4, MySDword)
    HRSOut "MySDword: ", SHex4 MySDword, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    MyWord = 58
    HRSOut "Write Binary number: ", Dec MyWord, CR, LF
    PrintDispInt(Bin6, MyWord)
    HRSOut "MyWord: ", Bin6 MyWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "END OF TEST: NOW COUNTING... ", CR, LF, CR, LF

    TestNumbers = 0
    TestLoop = 0
    MyDword = 899000
    Repeat
        HRSOut Dec MyDword,","
        PrintDispInt(Dec, MyDword)   '/ Extract the individual digits of MyDWord
        DelayMS 150
        MyDword = MyDword + 100001
        Inc TestNumbers
        If TestNumbers = 20 Then
            TestNumbers = 0
            HRSOut CR,LF
        EndIf
        Inc TestLoop 
    Until TestLoop > 90
    PrintDispInt(Dec, MyDword)      '/ Extract the individual digits of MyDWord
    HRSOut Dec MyDword
    HRSOut CR,LF,CR,LF
$endif
'/------------------------------------------------------------------------------
$if NumberDigits = 6
    HRSOut "Write Integer; 1 number: ", CR, LF
    MyDword = 6
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000
    
    HRSOut "Write Integer; 2 numbers: ", CR, LF
    MyDword = 12
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 3 numbers: ", CR, LF
    MyDword = 123
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 4 numbers: ", CR, LF
    MyDword = 1234
    PrintDispInt(Dec, MyDword)
    HRSOut "DISPVAL: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 5 numbers: ", CR, LF
    MyDword = 12345
    PrintDispInt(Dec, MyDword)
    HRSOut "DISPVAL: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 6 numbers: ", CR, LF
    MyDword = 123456
    PrintDispInt(Dec, MyDword)
    HRSOut "DISPVAL: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer HEX; 2 numbers: ", CR, LF
    MyDword = 12
    PrintDispInt(Hex2, MyDword)
    HRSOut "DISPVAL: ", Hex2 MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Integer HEX; 4 numbers: ", CR, LF
    MyDword = 1234
    PrintDispInt(Hex4, MyDword)
    HRSOut "DISPVAL: ", Hex4 MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Float, 3 decimals: ", CR, LF
    MyFloat = 3.145
    PrintDispFlt(Dec3, MyFloat)
    HRSOut "MyFloat: ", Dec3 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000
 
    HRSOut "Write Float, 1 decimal: ", CR, LF
    MyFloat = 3.145
    PrintDispFlt(Dec1, MyFloat)
    HRSOut "MyFloat: ", Dec1 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000 
    
    HRSOut "Write Negative number: SDword ", CR, LF
    MySDword = -12345
    PrintDispSign(SDec, MySDword)
    HRSOut "MySDword: ", SDec MySDword, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Negative number: SWord  ", CR, LF
    MySWord = -13367
    PrintDispSign(SDec, MySWord)
    HRSOut "MySDword: ", SDec MySWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write negative character + 1 number: ", CR, LF
    MyDword = 4567
    RsOut "-"
    PrintDispInt(Dec, MyDword)
    HRSOut "- MyDword: ", "-", Dec MyDword, CR, LF
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Negative HEX number: ", CR, LF
    MySDword = -5678
    PrintDispSign(SHex4, MySDword)
    HRSOut "MySDword: ", SHex4 MySDword, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    MyWord = 58
    HRSOut "Write Binary number: ", Dec MyWord, CR, LF
    PrintDispInt(Bin6, MyWord)
    HRSOut "MyWord: ", Bin6 MyWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "END OF TEST: NOW COUNTING... ", CR, LF, CR, LF

    TestNumbers = 0
    TestLoop = 0
    MyDword = 99000
    Repeat
        HRSOut Dec MyDword,","
        PrintDispInt(Dec, MyDword)   '/ Extract the individual digits of MyDWord
        DelayMS 150
        MyDword = MyDword + 11001
        Inc TestNumbers
        If TestNumbers = 20 Then
            TestNumbers = 0
            HRSOut CR,LF
        EndIf
        Inc TestLoop 
    Until TestLoop > 80
    PrintDispInt(Dec, MyDword)      '/ Extract the individual digits of MyDWord
    HRSOut Dec MyDword
    HRSOut CR,LF,CR,LF
$endif
'/------------------------------------------------------------------------------    
$if NumberDigits = 5
    HRSOut "Write Integer; 1 number: ", CR, LF
    MyDword = 6
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000
    
    HRSOut "Write Integer; 2 numbers: ", CR, LF
    MyDword = 12
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 3 numbers: ", CR, LF
    MyDword = 123
    PrintDispInt(Dec, MyDword)
    HRSOut "MyDword: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 4 numbers: ", CR, LF
    MyDword = 1234
    PrintDispInt(Dec, MyDword)
    HRSOut "DISPVAL: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 5 numbers: ", CR, LF
    MyDword = 12345
    PrintDispInt(Dec, MyDword)
    HRSOut "DISPVAL: ", Dec MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer HEX; 2 numbers: ", CR, LF
    MyDword = 12
    PrintDispInt(Hex2, MyDword)
    HRSOut "DISPVAL: ", Hex2 MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Integer HEX; 4 numbers: ", CR, LF
    MyDword = 1234
    PrintDispInt(Hex4, MyDword)
    HRSOut "DISPVAL: ", Hex4 MyDword, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Float, 3 decimals: ", CR, LF
    MyFloat = 3.145
    PrintDispFlt(Dec3, MyFloat)
    HRSOut "MyFloat: ", Dec3 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000
 
    HRSOut "Write Float, 1 decimal: ", CR, LF
    MyFloat = 3.145
    PrintDispFlt(Dec1, MyFloat)
    HRSOut "MyFloat: ", Dec1 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000 
    
    HRSOut "Write Negative number: SDword ", CR, LF
    MySDword = -1234
    PrintDispSign(SDec, MySDword)
    HRSOut "MySDword: ", SDec MySDword, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Negative number: SWord  ", CR, LF
    MySWord = -1336
    PrintDispSign(SDec, MySWord)
    HRSOut "MySDword: ", SDec MySWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write minus character + 1 number: ", CR, LF
    MyDword = 4567
    RsOut "-"
    PrintDispInt(Dec, MyDword)
    HRSOut "- MyDword: ", "-", Dec MyDword, CR, LF
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Negative HEX number: ", CR, LF
    MySDword = -678
    PrintDispSign(SHex4, MySDword)
    HRSOut "MySDword: ", SHex4 MySDword, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    MyWord = 12
    HRSOut "Write Binary number: ", Dec MyWord, CR, LF
    PrintDispInt(Bin4, MyWord)
    HRSOut "MyWord: ", Bin4 MyWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "END OF TEST: NOW COUNTING... ", CR, LF, CR, LF

    TestNumbers = 0
    TestLoop = 0
    MyDword = 9900
    Repeat
        HRSOut Dec MyDword,","
        PrintDispInt(Dec, MyDword)   '/ Extract the individual digits of MyDWord
        DelayMS 150
        MyDword = MyDword + 1101
        Inc TestNumbers
        If TestNumbers = 20 Then
            TestNumbers = 0
            HRSOut CR,LF
        EndIf
        Inc TestLoop 
    Until TestLoop > 80
    PrintDispInt(Dec, MyDword)      '/ Extract the individual digits of MyDWord
    HRSOut Dec MyDword
    HRSOut CR,LF,CR,LF
$endif
'/------------------------------------------------------------------------------
$if NumberDigits = 4
    HRSOut "Write Integer; 1 number: ", CR, LF
    MyWord = 6
    PrintDispInt(Dec, MyWord)
    HRSOut "MyWord: ", Dec MyWord, CR, LF        
    HRSOut CR, LF
    DelayMS 1000
    
    HRSOut "Write Integer; 2 numbers: ", CR, LF
    MyWord = 12
    PrintDispInt(Dec, MyWord)
    HRSOut "MyWord: ", Dec MyWord, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 3 numbers: ", CR, LF
    MyWord = 123
    PrintDispInt(Dec, MyWord)
    HRSOut "MyWord: ", Dec MyWord, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer; 4 numbers: ", CR, LF
    MyWord = 1234
    PrintDispInt(Dec, MyWord)
    HRSOut "MyWord: ", Dec MyWord, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer HEX; 2 numbers: ", CR, LF
    MyWord = 12
    PrintDispInt(Hex2, MyWord)
    HRSOut "MyWord: ", Hex2 MyWord, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Integer HEX; 4 numbers: ", CR, LF
    MyWord = 234
    PrintDispInt(Hex4, MyWord)
    HRSOut "MyWord: ", Hex4 MyWord, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Float, 2 decimals: ", CR, LF
    MyFloat = 3.14
    PrintDispFlt(Dec2, MyFloat)
    HRSOut "MyFloat: ", Dec2 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000
 
    HRSOut "Write Float, 1 decimal: ", CR, LF
    MyFloat = 3.14
    PrintDispFlt(Dec1, MyFloat)
    HRSOut "MyFloat: ", Dec1 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000 
    
    HRSOut "Write Negative number: SWord ", CR, LF
    MySWord = -123
    PrintDispSign(SDec, MySWord)
    HRSOut "MySWord: ", SDec MySWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Negative number: SWord  ", CR, LF
    MySWord = -538
    PrintDispSign(SDec, MySWord)
    HRSOut "MySDword: ", SDec MySWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write negative character + 1 number: ", CR, LF
    MyWord = 567
    RsOut "-"
    PrintDispInt(Dec, MyWord)
    HRSOut "- MyWord: ", "-", Dec MyWord, CR, LF
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Negative HEX number: ", CR, LF
    MySWord = -125
    PrintDispSign(SHex2, MySWord)
    HRSOut "MySWord: ", SHex2 MySWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    MyWord = 12
    HRSOut "Write Binary number: ", Dec MyWord, CR, LF
    PrintDispInt(Bin4, MyWord)
    HRSOut "MyWord: ", Bin4 MyWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "END OF TEST: NOW COUNTING... ", CR, LF, CR, LF

    TestNumbers = 0
    TestLoop = 0
    MyWord = 900
    Repeat
        HRSOut Dec MyWord,","
        PrintDispInt(Dec, MyWord)   '/ Extract the individual digits of MyWord
        DelayMS 150
        MyWord = MyWord + 101
        Inc TestNumbers
        If TestNumbers = 25 Then
            TestNumbers = 0
            HRSOut CR,LF
        EndIf
        Inc TestLoop 
    Until TestLoop > 89
    PrintDispInt(Dec, MyWord)       '/ Extract the individual digits of MyWord
    HRSOut Dec MyWord
    HRSOut CR,LF,CR,LF
$endif
'/------------------------------------------------------------------------------        
$if NumberDigits = 3
    HRSOut "Write Integer; 1 number: ", CR, LF
    MyWord = 9
    PrintDispInt(Dec, MyWord)
    HRSOut "MyWord: ", Dec MyWord, CR, LF        
    HRSOut CR, LF
    DelayMS 1000
    
    HRSOut "Write Integer; 2 numbers: ", CR, LF
    MyWord = 36
    PrintDispInt(Dec, MyWord)
    HRSOut "MyWord: ", Dec MyWord, CR, LF        
    HRSOut CR, LF
    DelayMS 1000
    
    HRSOut "Write Integer; 3 numbers: ", CR, LF
    MyWord = 123
    PrintDispInt(Dec, MyWord)
    HRSOut "MyWord: ", Dec MyWord, CR, LF        
    HRSOut CR, LF
    DelayMS 1000

    HRSOut "Write Integer HEX; 2 numbers: ", CR, LF
    MyWord = 12
    PrintDispInt(Hex2, MyWord)
    HRSOut "MyWord: ", Hex2 MyWord, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Integer HEX; 2 numbers: ", CR, LF
    MyWord = 93
    PrintDispInt(Hex3, MyWord)
    HRSOut "MyWord: ", Hex3 MyWord, CR, LF        
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Float, 1 decimal: ", CR, LF
    MyFloat = 3.14
    PrintDispFlt(Dec1, MyFloat)
    HRSOut "MyFloat: ", Dec1 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000
 
    HRSOut "Write Float, 0 decimal: ", CR, LF
    MyFloat = 3.14
    PrintDispFlt(Dec0, MyFloat)
    HRSOut "MyFloat: ", Dec0 MyFloat, CR, LF 
    HRSOut CR, LF
    DelayMS 2000 
    
    HRSOut "Write Negative number: SWord  ", CR, LF
    MySWord = -16
    PrintDispSign(SDec, MySWord)
    HRSOut "MySWord: ", SDec MySWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write negative character + 1 number: ", CR, LF
    MyWord = 56
    RsOut "-"
    PrintDispInt(Dec, MyWord)
    HRSOut "- MyWord: ", "-", Dec MyWord, CR, LF
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "Write Negative HEX number: ", CR, LF
    MySWord = -79
    PrintDispSign(SHex2, MySWord)
    HRSOut "MySWord: ", SHex2 MySWord, CR, LF 
    HRSOut CR, LF
    DelayMS 2000

    HRSOut "END OF TEST: NOW COUNTING... ", CR, LF, CR, LF

    TestNumbers = 0
    TestLoop = 0
    MyWord = 99
    Repeat
        HRSOut Dec MyWord,","
        PrintDispInt(Dec, MyWord)   '/ Extract the individual digits of MyWord
        DelayMS 150
        MyWord = MyWord + 14
        Inc TestNumbers
        If TestNumbers = 25 Then
            TestNumbers = 0
            HRSOut CR,LF
        EndIf
        Inc TestLoop 
    Until TestLoop > 63
    PrintDispInt(Dec, MyWord)       '/ Extract the individual digits of MyWord
    HRSOut Dec MyWord
    HRSOut CR,LF,CR,LF
$endif
'/------------------------------------------------------------------------------
    DelayMS 2000
    GoTo Multiplex     
'===============================================================================        
    End
'===============================================================================
        
